@@ -246,13 +246,23 @@ class CreateAccessRulesResponse(AbstractModel):
 
     def __init__(self):
         r"""
+        :param AccessRules: 权限规则列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type AccessRules: list of AccessRule
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
+        self.AccessRules = None
         self.RequestId = None
 
 
     def _deserialize(self, params):
+        if params.get("AccessRules") is not None:
+            self.AccessRules = []
+            for item in params.get("AccessRules"):
+                obj = AccessRule()
+                obj._deserialize(item)
+                self.AccessRules.append(obj)
         self.RequestId = params.get("RequestId")
 
 
@@ -281,6 +291,8 @@ class CreateFileSystemRequest(AbstractModel):
         :type EnableRanger: bool
         :param RangerServiceAddresses: Ranger地址列表，默认为空数组
         :type RangerServiceAddresses: list of str
+        :param Tags: 多个资源标签，可以为空数组
+        :type Tags: list of Tag
         """
         self.FileSystemName = None
         self.CapacityQuota = None
@@ -291,6 +303,7 @@ class CreateFileSystemRequest(AbstractModel):
         self.RootInodeGroup = None
         self.EnableRanger = None
         self.RangerServiceAddresses = None
+        self.Tags = None
 
 
     def _deserialize(self, params):
@@ -303,6 +316,12 @@ class CreateFileSystemRequest(AbstractModel):
         self.RootInodeGroup = params.get("RootInodeGroup")
         self.EnableRanger = params.get("EnableRanger")
         self.RangerServiceAddresses = params.get("RangerServiceAddresses")
+        if params.get("Tags") is not None:
+            self.Tags = []
+            for item in params.get("Tags"):
+                obj = Tag()
+                obj._deserialize(item)
+                self.Tags.append(obj)
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -892,6 +911,12 @@ class DescribeFileSystemResponse(AbstractModel):
         :param DegradeCapacityUsed: 已使用COS低频存储容量（byte）
 注意：此字段可能返回 null，表示取不到有效值。
         :type DegradeCapacityUsed: int
+        :param DeepArchiveCapacityUsed: 已使用COS深度归档存储容量（byte）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type DeepArchiveCapacityUsed: int
+        :param IntelligentCapacityUsed: 已使用COS智能分层存储容量（byte）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IntelligentCapacityUsed: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -900,6 +925,8 @@ class DescribeFileSystemResponse(AbstractModel):
         self.ArchiveCapacityUsed = None
         self.StandardCapacityUsed = None
         self.DegradeCapacityUsed = None
+        self.DeepArchiveCapacityUsed = None
+        self.IntelligentCapacityUsed = None
         self.RequestId = None
 
 
@@ -911,6 +938,8 @@ class DescribeFileSystemResponse(AbstractModel):
         self.ArchiveCapacityUsed = params.get("ArchiveCapacityUsed")
         self.StandardCapacityUsed = params.get("StandardCapacityUsed")
         self.DegradeCapacityUsed = params.get("DegradeCapacityUsed")
+        self.DeepArchiveCapacityUsed = params.get("DeepArchiveCapacityUsed")
+        self.IntelligentCapacityUsed = params.get("IntelligentCapacityUsed")
         self.RequestId = params.get("RequestId")
 
 
@@ -1340,6 +1369,10 @@ class LifeCycleRule(AbstractModel):
         :type Status: int
         :param CreateTime: 创建时间
         :type CreateTime: str
+        :param Summary: 生命周期规则当前路径具体存储量
+        :type Summary: :class:`tencentcloud.chdfs.v20201112.models.Summary`
+        :param LastSummaryTime: Summary更新时间
+        :type LastSummaryTime: str
         """
         self.LifeCycleRuleId = None
         self.LifeCycleRuleName = None
@@ -1347,6 +1380,8 @@ class LifeCycleRule(AbstractModel):
         self.Transitions = None
         self.Status = None
         self.CreateTime = None
+        self.Summary = None
+        self.LastSummaryTime = None
 
 
     def _deserialize(self, params):
@@ -1361,6 +1396,10 @@ class LifeCycleRule(AbstractModel):
                 self.Transitions.append(obj)
         self.Status = params.get("Status")
         self.CreateTime = params.get("CreateTime")
+        if params.get("Summary") is not None:
+            self.Summary = Summary()
+            self.Summary._deserialize(params.get("Summary"))
+        self.LastSummaryTime = params.get("LastSummaryTime")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1768,6 +1807,56 @@ class RestoreTask(AbstractModel):
         
 
 
+class Summary(AbstractModel):
+    """生命周期规则当前路径具体存储量信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param CapacityUsed: 已使用容量（byte）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CapacityUsed: int
+        :param StandardCapacityUsed: 已使用COS标准存储容量（byte）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type StandardCapacityUsed: int
+        :param DegradeCapacityUsed: 已使用COS低频存储容量（byte）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type DegradeCapacityUsed: int
+        :param ArchiveCapacityUsed: 已使用COS归档存储容量（byte）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ArchiveCapacityUsed: int
+        :param DeepArchiveCapacityUsed: 已使用COS深度归档存储容量（byte）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type DeepArchiveCapacityUsed: int
+        :param IntelligentCapacityUsed: 已使用COS智能分层存储容量（byte）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IntelligentCapacityUsed: int
+        """
+        self.CapacityUsed = None
+        self.StandardCapacityUsed = None
+        self.DegradeCapacityUsed = None
+        self.ArchiveCapacityUsed = None
+        self.DeepArchiveCapacityUsed = None
+        self.IntelligentCapacityUsed = None
+
+
+    def _deserialize(self, params):
+        self.CapacityUsed = params.get("CapacityUsed")
+        self.StandardCapacityUsed = params.get("StandardCapacityUsed")
+        self.DegradeCapacityUsed = params.get("DegradeCapacityUsed")
+        self.ArchiveCapacityUsed = params.get("ArchiveCapacityUsed")
+        self.DeepArchiveCapacityUsed = params.get("DeepArchiveCapacityUsed")
+        self.IntelligentCapacityUsed = params.get("IntelligentCapacityUsed")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class Tag(AbstractModel):
     """资源标签。
 
@@ -1805,7 +1894,7 @@ class Transition(AbstractModel):
         r"""
         :param Days: 触发时间（单位天）
         :type Days: int
-        :param Type: 转换类型（1：归档；2：删除；3：低频）
+        :param Type: 转换类型（1：归档；2：删除；3：低频；4：深度归档；5：智能分层）
         :type Type: int
         """
         self.Days = None
